summaryrefslogtreecommitdiffstats
path: root/chrome/browser/first_run.cc
diff options
context:
space:
mode:
authorevan@chromium.org <evan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-28 23:56:05 +0000
committerevan@chromium.org <evan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-28 23:56:05 +0000
commit666989abf69d6928f1be23669ab151dc95024bb1 (patch)
treea20ac2ca8e368fed4a1b030f03ff551d50a8e091 /chrome/browser/first_run.cc
parentf7772088ff4e4579837bc30d862b9290529eea98 (diff)
downloadchromium_src-666989abf69d6928f1be23669ab151dc95024bb1.zip
chromium_src-666989abf69d6928f1be23669ab151dc95024bb1.tar.gz
chromium_src-666989abf69d6928f1be23669ab151dc95024bb1.tar.bz2
linux: remove the word "Alpha" from all UI.
It mostly confuses the press. Review URL: http://codereview.chromium.org/113978 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@17137 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/first_run.cc')
-rw-r--r--chrome/browser/first_run.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/first_run.cc b/chrome/browser/first_run.cc
index 540aa61..f0b0f74 100644
--- a/chrome/browser/first_run.cc
+++ b/chrome/browser/first_run.cc
@@ -25,7 +25,7 @@ const char kSentinelFile[] = "First Run";
// On other platforms de intentionally use a different file name, so
// when the remainder of this file is implemented, we can switch to
// the proper file name and users will get the first run interface again.
-const char kSentinelFile[] = "First Run Alpha";
+const char kSentinelFile[] = "First Run Dev";
#endif
// Gives the full path to the sentinel file. The file might not exist.
@@ -43,7 +43,7 @@ bool GetFirstRunSentinelFilePath(FilePath* path) {
return false;
}
#else
// TODO(port): logic as above. Not important for our "First Run Alpha" file.
if (!PathService::Get(chrome::DIR_USER_DATA, &first_run_sentinel))
return false;
#endif
@@ -43,7 +43,7 @@ bool GetFirstRunSentinelFilePath(FilePath* path) {
}
#else
- // TODO(port): logic as above. Not important for our "First Run Alpha" file.
+ // TODO(port): logic as above. Not important for our "First Run Dev" file.
if (!PathService::Get(chrome::DIR_USER_DATA, &first_run_sentinel))
return false;